--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 43403 $"):match("%d+"))

local Sphere = Sphere
local Sphere_SubButtons = Sphere:NewModule("SubButtons", "AceEvent-2.0", "AceHook-2.1")
local self = Sphere_SubButtons
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-10 16:19:55 -0400 (Tue, 10 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Adds Buttons to the Sphere"

--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local L = Sphere:L("Sphere_SubButtons")

local data = {
	menuCount = 0,
	subCount = 0,
	cursorType = nil,
	cursorInfo1 = nil,
	cursorInfo2 = nil,
	cursorHasItem = false,
}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_SubButtons:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("SubButtons")
	Sphere:RegisterDefaults("SubButtons", "char", {
		settings = {
			scale = 0.90,
			offSet = 7,
		},
		SphereSubBar1 = {
			buttons = {},
		},
		SphereSubBar2 = {
			buttons = {},
		},
		SphereSubBar3 = {
			buttons = {},
		},
		SphereSubBar4 = {
			buttons = {},
		},
		SphereSubBar5 = {
			buttons = {},
		},
		SphereSubBar6 = {
			buttons = {},
		},
		SphereSubBar7 = {
			buttons = {},
		},
		SphereSubBar8 = {
			buttons = {},
		},
		SphereSubBar9 = {
			buttons = {},
		},
		SphereSubBar10 = {
			buttons = {},
		},
		
	})

	Sphere_SubButtons:CreateSubButtons()
end

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
Sphere_SubButtons:RegisterSphereOption({
	name = L["Sub Buttons"],
	desc = L["Change the Sub Buttons options."],
	type = 'group',
	args = {
		appearance = {
			name = L["Appearance"],
			desc = L["Change how the Sub Buttons Appearance looks in general."],
			type = 'group',
			args = {
				size = {
					name = L["Size"],
					desc = L["Set how large the Sub Buttons are."],
					type = 'range',
					min = 0.50,
					max = 2,
					step = 0.01,
					bigStep = 0.05,
					get = function()
						return self.db.char.settings.scale
					end,
					set = "SetScale"
				},
				offSet = {
					name = L["offSet"],
					desc = L["Set how much of an offSet the Sub Buttons are."],
					type = 'range',
					min = 0,
					max = 10,
					step = 1,
					bigStep = 2,
					get = function()
						return self.db.char.settings.offSet
					end,
					set = "SetOffSet"
				},
			},
		},
	}

})

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_SubButtons:OnEnable()
	self:ScheduleEvent("Sphere_SubButtons_PostEnable", self.OnPostEnable, 1, self)
end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_SubButtons:OnDisable()
	self:UnregisterAllEvents();

end

--- ========================================================= ---
---  On Post Enable
--- ========================================================= ---
function Sphere_SubButtons:OnPostEnable()
	for indexMenu = 1, 10 do
		for index = 1, 10 do 
			Sphere_Buttons:SetIcon(getglobal("SphereButton"..indexMenu.."Sub"..index))
		end
	end
end

--- ========================================================= ---
---  Set Scale
--- ========================================================= ---
function Sphere_SubButtons:SetScale(value)
	if value then
		self.db.char.settings.scale = value
	else
		value = self.db.char.settings.scale
	end
	
	for indexMenu = 1, 10 do
		for index = 1, 10 do 
			getglobal("SphereButton"..indexMenu.."Sub"..index):SetScale(value)
		end
	end
end

--- ========================================================= ---
---  Set offSet
--- ========================================================= ---
function Sphere_SubButtons:SetOffSet(value)
	if value then
		self.db.char.settings.offSet = value
	else
		value = self.db.char.settings.offSet
	end
	
	local index = 0
	local xDir, xLoc, yLoc
	local offsetY = {30, 6, 0, 0, -6, -30, -6, 0, 0, 6}
	local offSet = self.db.char.settings.offSet
	
	for indexMenu = 1, 10 do 
		local anchor = "SphereBar" .. indexMenu
		xDir = 1;
		if (indexMenu > 6) then
			xDir = -1;
		end
		for xLoc = 0, (320 - 32), 32 do 
			if (index >= 10) then
				index = 1
			else
				index = index + 1;
			end
			local name = "SphereButton"..indexMenu.."Sub"..index
			getglobal(name):ClearAllPoints()
			if (xDir == 1) then
				if (xLoc == 0) then
					getglobal(name):SetPoint("LEFT", getglobal(anchor), "RIGHT", offSet, offsetY[indexMenu]);
				else
					getglobal(name):SetPoint("LEFT", getglobal("SphereButton" .. tostring(indexMenu) .. "Sub" .. tostring(index - 1)), "RIGHT", offSet, 0);
				end
			else
				if (xLoc == 0) then
					getglobal(name):SetPoint("RIGHT", getglobal(anchor), "LEFT", -offSet, offsetY[indexMenu]);
				else
					getglobal(name):SetPoint("RIGHT", getglobal("SphereButton" .. tostring(indexMenu) .. "Sub" .. tostring(index - 1)), "LEFT", -offSet, 0);
				end
			end
		end
	end
end

--- ========================================================= ---
---  Create (10) Bars
--- ========================================================= ---
function Sphere_SubButtons:CreateSubButtons()

	for indexMenu = 1, 10 do
		vals = self.db.char["SphereSubBar"..indexMenu]
		for index = 1, 10 do 
			local btn = Sphere_Buttons:CreateButton(index, "SphereButton"..indexMenu.."Sub"..index, "Sub", vals.buttons, getglobal("SphereBar"..indexMenu), "SphereSubBar"..indexMenu)
		end
	end
	
	Sphere_SubButtons:SetOffSet()
	Sphere_SubButtons:SetScale()
	
end